@@ -3,24 +3,59 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Return the borders of states and provinces
 
-our $VERSION = '0.0102';
+our $VERSION = '0.0103';
 
 use strictures 2;
-use Carp qw(croak);
 use Moo;
 use namespace::clean;
 
 
 has country => (
     is      => 'ro',
-    isa     => sub { croak "$_[0] is not valid" unless $_[0] =~ /^[a-zA-Z]+$/ },
+    isa     => sub { die "$_[0] is not valid" unless $_[0] =~ /^[a-zA-Z]+$/ },
     default => sub { 'usa' },
 );
 
+has _brazil => (
+    is       => 'ro',
+    init_arg => undef,
+    default  => sub {
+      {
+        AC => [qw(AM RO)],
+        AL => [qw(BA PE SE)],
+        AM => [qw(AC MT RO RR)],
+        AP => [qw(PA)],
+        BA => [qw(ES MG GO TO PI PE AL SE)],
+        CE => [qw(RN PB PE PI )],
+        DF => [qw(GO MG)],
+        ES => [qw(RJ MG BA)],
+        GO => [qw(DF MG MS MT TO BA)],
+        MA => [qw(PI TO PA)],
+        MG => [qw(SP MS GO DF BA ES RJ)],
+        MS => [qw(MT GO MG SP PR)],
+        MT => [qw(RO AM PA TO GO MS)],
+        PA => [qw(MT AM RR AP MA TO)],
+        PB => [qw(PE CE RN)],
+        PE => [qw(AL BA PI CE PB)],
+        PI => [qw(BA TO MA CE PE)],
+        PR => [qw(MS SP SC)],
+        RJ => [qw(SP MG ES)],
+        RN => [qw(PB CE)],
+        RO => [qw(AC AM MT)],
+        RR => [qw(AM PA)],
+        RS => [qw(SC)],
+        SC => [qw(RS PR)],
+        SE => [qw(BA AL)],
+        SP => [qw(PR MS MG RJ)],
+        TO => [qw(GO MT PA MA PI BA)],
+      }
+    },
+);
+
 has _canada => (
-    is      => 'ro',
-    isa     => sub { croak "$_[0] is not valid" unless ref $_[0] eq 'HASH' },
-    default => sub {
+    is       => 'ro',
+    init_arg => undef,
+    default  => sub {
       {
         AB => [qw(BC NT SK)],
         BC => [qw(AB NT YT)],
@@ -40,9 +75,9 @@ has _canada => (
 );
 
 has _usa => (
-    is      => 'ro',
-    isa     => sub { croak "$_[0] is not valid" unless ref $_[0] eq 'HASH' },
-    default => sub {
+    is       => 'ro',
+    init_arg => undef,
+    default  => sub {
       {
         AK => [],
         AL => [qw(FL GA MS TN)],
@@ -128,7 +163,7 @@ Geography::States::Borders - Return the borders of states and provinces
 
 =head1 VERSION
 
-version 0.0102
+version 0.0103
 
 =head1 SYNOPSIS
 
@@ -141,7 +176,7 @@ version 0.0102
 
 C<Geography::States::Borders> returns the borders of states and provinces.
 
-* Currently the only recognized countries are the USA and Canada.
+* Currently the only recognized countries are Canada, Brazil, and the USA.
 
 =head1 ATTRIBUTES
 
